window {
	display: block;
	width: 100%;
}

tree {
	display: table;
	background-color: lightGray;
	border: none;
	border-spacing: 0px;
	border-collapse: collapse;
	width: 75%;
}

treeitem {
	display: table-row;
    visibility: collapse; 
}

treehead {
	display: table-header-group;
}

treebody {
	display: table-row-group;	
}

treehead > treeitem { 
    visibility: visible; 
} 
treeitem[open] > treechildren > treeitem { 
    visibility: visible; 
}
treebody > treeitem { 
    visibility: visible; 
} 


treecell {
	display: table-cell;
	color: black;
	font-family: Verdana;
	font-size: 10pt;
}

treehead treeitem treecell {
	background-color: #a0a0a0;
	border: thin black solid;
	color: black;
}

treeicon {
	display: list-item;
	list-style-image: url("http://rava/~hyatt/ClosedRead.gif");
	list-style-position: inside;
}

treecell[selectedcell] {
	background-color: lightBlue;
}


